@@ -9,7 +9,7 @@ class Video:
         self.path = path
         self.shape = shape
         self.show_video = show_video
-        self.window_name = self.path or "webcam"
+        self.window_name = window_name or "webcam"
         self.pre_process = lambda img: img if self.shape is None else cv2.resize(img, self.shape, interpolation=cv2.INTER_AREA)
         self.__load_video()
 
